@@ -81,6 +81,11 @@ QTM_USE_NAMESPACE
         QWidget(parent),
         ui(new Ui::Fastsms)
 {
+    //Manage singlas from DBus
+    new busManagerServ(this);
+    registerService();
+    //
+
     ui->setupUi(this);
     setWindowTitle("FastSMS");
 
