@@ -27,14 +27,15 @@ int main(int argc, char *argv[])
     a.setAutoSipEnabled(false);
     a.setApplicationVersion(APP_VERSION);
 
-    fastsms w;
+    Fastsms w;
 
     a.connect(&a, SIGNAL(aboutToQuit()), &w, SLOT(saveDictionaryOnExit()));
 
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
-    w.show();    
+    w.show();
+    //w.showFullScreen();
 #endif
 
     return a.exec();
